#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod-core
version:              1.6.20.1
visibility:           public
id:                   yesod-core-1.6.20.1-AZEcK2kpTthHerC9UzYV34
key:                  yesod-core-1.6.20.1-AZEcK2kpTthHerC9UzYV34
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>

category:             Web, Yesod
abi:                  72464487d7d64e4e0e6d8e47b36441fd
exposed:              True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Internal Yesod.Core.Json
    Yesod.Core.Types Yesod.Core.Unsafe Yesod.Core.Widget
    Yesod.Routes.TH.Types

hidden-modules:
    Yesod.Core.Internal.Session Yesod.Core.Internal.Request
    Yesod.Core.Class.Handler Yesod.Core.Internal.Util
    Yesod.Core.Internal.Response Yesod.Core.Internal.Run
    Yesod.Core.Internal.TH Yesod.Core.Internal.LiteApp
    Yesod.Core.Class.Yesod Yesod.Core.Class.Dispatch
    Yesod.Core.Class.Breadcrumbs Yesod.Core.TypeCache Paths_yesod_core
    Yesod.Routes.TH Yesod.Routes.Class Yesod.Routes.Parse
    Yesod.Routes.Overlap Yesod.Routes.TH.Dispatch
    Yesod.Routes.TH.RenderRoute Yesod.Routes.TH.ParseRoute
    Yesod.Routes.TH.RouteAttrs

import-dirs:          /usr/lib/ghc-8.10.5/site-local/yesod-core-1.6.20.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/yesod-core-1.6.20.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/yesod-core-1.6.20.1
hs-libraries:         HSyesod-core-1.6.20.1-AZEcK2kpTthHerC9UzYV34
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    auto-update-0.1.6-7K4JToCmNkHJlkSexgjzA2 base-4.14.2.0
    blaze-html-0.9.1.2-3gWJOEFN3Rn7Mv2jAJdKwl
    blaze-markup-0.8.2.8-8RebaU3zReM4AoTFuL4PYs bytestring-0.10.12.0
    case-insensitive-1.2.1.0-G5jOpOHgp1lAnadtJPMHHB
    cereal-0.5.8.1-4r85zOZIbEW4fo8WFnBuTl
    clientsession-0.9.1.2-Cx2mUejZNOI3hjS5yIhZLB
    conduit-1.3.4.1-GHgRKpknFuqDscwzVojbiE
    conduit-extra-1.3.5-6wbdzvOjyuAGkpGhMnpbur containers-0.6.4.1
    cookie-0.4.5-DRjKUovO6l159RRdguKqPl deepseq-1.4.4.0
    entropy-0.4.1.6-mwZ4jE2F7MEzr0ctFVs6J
    fast-logger-3.0.5-I5dfCGxOK271HLzqt5yeow
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB
    memory-0.16.0-E1gXzMJzgEcJ8QhI9dLs6S
    monad-logger-0.3.36-1GrKwR43Dhh83kQQb62BZS mtl-2.2.2
    parsec-3.1.14.0 path-pieces-0.2.1-5gT7wFDsgDLEW6f8EG31Nu
    primitive-0.7.1.0-H44eQ1j8hQJ3Kj2SFx0Ivh
    random-1.2.0-GZbCBA9NAlUBaVRSIi1HYu
    resourcet-1.2.4.2-7etOfd8fePh2l91avxjTIe
    shakespeare-2.0.25-9PoqIRIh6zmA0h3TqA8xt9 template-haskell-2.16.0.0
    text-1.2.4.1 time-1.9.3 transformers-0.5.6.2
    unix-compat-0.5.3-1KqjYp6svTH6EdzCzH8QEz
    unliftio-0.2.18-5P4UivtPmWZvk4Y5NpZt0
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp
    wai-3.2.3-6NrdunSiuKK6vnccK2cwty
    wai-extra-3.1.6-FKz4MHJx3sl2f6Nl0w7kAe
    wai-logger-2.3.6-D38BZlKnHPTKsiCW915NQw
    warp-3.3.16-JCGQXtllRgYC0aGKpmQh8V
    word8-0.1.3-C9wcaZKtRvf9CTebSJFNpx

haddock-interfaces:   /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html:         /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

